# Changelog

## 0.1.1 (2024-09-05)

Full Changelog: [v0.1.0...v0.1.1](https://github.com/bespokelabsai/bespokelabs-python/compare/v0.1.0...v0.1.1)

### Features

* **api:** update via SDK Studio ([#7](https://github.com/bespokelabsai/bespokelabs-python/issues/7)) ([052e2ed](https://github.com/bespokelabsai/bespokelabs-python/commit/052e2ede8c634b31dc4075d57b88bfc7fdb9cb59))


### Chores

* pyproject.toml formatting changes ([#9](https://github.com/bespokelabsai/bespokelabs-python/issues/9)) ([0f5c6e8](https://github.com/bespokelabsai/bespokelabs-python/commit/0f5c6e84656c6b48640ffb4bbb47780e94a9ed4a))

## 0.1.0 (2024-09-04)

Full Changelog: [v0.1.0-alpha.1...v0.1.0](https://github.com/bespokelabsai/bespokelabs-python/compare/v0.1.0-alpha.1...v0.1.0)

### Features

* **api:** update via SDK Studio ([#4](https://github.com/bespokelabsai/bespokelabs-python/issues/4)) ([88ab107](https://github.com/bespokelabsai/bespokelabs-python/commit/88ab107c0b748171107610ca7996a7e7cd34cfc2))

## 0.1.0-alpha.1 (2024-09-04)

Full Changelog: [v0.0.1-alpha.0...v0.1.0-alpha.1](https://github.com/bespokelabsai/bespokelabs-python/compare/v0.0.1-alpha.0...v0.1.0-alpha.1)

### Features

* **api:** update via SDK Studio ([54053fb](https://github.com/bespokelabsai/bespokelabs-python/commit/54053fb6a75d481609d33102f198e3dc91b3ba60))
* **api:** update via SDK Studio ([7fe5a36](https://github.com/bespokelabsai/bespokelabs-python/commit/7fe5a367cd4ef0e6d06f960bcd49bf2845223326))
* **api:** update via SDK Studio ([cdcc900](https://github.com/bespokelabsai/bespokelabs-python/commit/cdcc900b8e9a37045889fd96199dc866b60c076d))
* **api:** update via SDK Studio ([003129a](https://github.com/bespokelabsai/bespokelabs-python/commit/003129a7672a76149ebaa139cdae241e296b1fcd))
* **api:** update via SDK Studio ([224b3c9](https://github.com/bespokelabsai/bespokelabs-python/commit/224b3c9a2751a732e1d1c9a3426caf6df0882960))
* **api:** update via SDK Studio ([85409ce](https://github.com/bespokelabsai/bespokelabs-python/commit/85409cebb1bea4e92d834374edfe16669a7a41eb))
* **api:** update via SDK Studio ([b0632a3](https://github.com/bespokelabsai/bespokelabs-python/commit/b0632a3db7f72e9556590d84aa744fe4a50b12af))


### Chores

* go live ([#1](https://github.com/bespokelabsai/bespokelabs-python/issues/1)) ([a01a998](https://github.com/bespokelabsai/bespokelabs-python/commit/a01a998870299ef7acf0432382b1868908da319e))
